
'*******************************************************************
' Stack Fits Images.txt
' James L. Jones, 2005                                                               
'                                                                                          
'This script utilizes MaxIm to stack images in the Fits Format.          
'The images to be stacked are placed in a folder.  Nothing else        
'Can be in the folder.  Drag and drop the image folder to the           
'script icon.  The script will tell you how many images you have      
'in the folder and ask how many images you want in each stack.                                                                                                 *
'Sit back and watch.                                                                                                             
'The stacked images and a log file will be placed in the image folder.
' 
'Thanks to Bob Denny for showing me the Drag and Drop thing.
'                                                                                        
'******************************************************************

Option Explicit
Dim Doc, Apps, AllDocs, Path, collArgs, fso, f, fc, count, fl, SavePath
Dim Images(1500), Img(1200), i, ii, j, Item(10), N, Shift, jint, jmod, k, StackIndex
Dim LineTxt(1500), ImageText(1500), DateTime, MidPoint, ts, cso, TxtLog, indx, jj, kk
Set collArgs = WScript.Arguments
Call Drag_Drop()

'*********************************************
'     Get Collection of file Names                        
'*********************************************
Set fso = CreateObject("Scripting.FileSystemObject")
Set f = fso.GetFolder(collArgs(0))
Set fc = f.Files
Call MoveColl()
Call InputData()
Call Calculate()
'**********************************************************
'    jint = number of whole stacks                       
'    N = Number of images in each whole stack            
'    jmod = number of images in partial stack, if any    
'    k = first image in stack                            
'    k+N-1 = Last image in stack                         
'    ii = MaxIm Image Number                             
'    i = Image being oppened from Images()               
'**********************************************************
Indx = 0
k = 0
For StackIndex = 0 To jint-1
	ii = 0
	
		For i = k To k+N-1
			Call  OpenImage(i, ii)
			ii = ii + 1
		Next
	k = k + Shift
	Call Stack_Save()	
	Call CloseImages()
Next
Call CreateLog()
ts.close

'*********************************************
'                Drag and Drop              
'*********************************************
Sub Drag_Drop()
count = 0
If collArgs.Count = 0 Then
      WScript.Echo _
"Drag a folder of FITS images to this icon to stack."
    	WScript.Quit
End If
End Sub

'*****************************************************************
'    Move collection of file names (fc) to array (Images())     
'*****************************************************************
Sub MoveColl()
count = fc.Count 
i = 0
For Each fl In fc
	Images(i) = fl.name
	i=i+1
Next
End Sub

'***********************************************
'    Input number of images in each stack      
'***********************************************
Sub InputData()
N = InputBox("There are " & fc.count & " images in the folder." & vbCrlf & "How many Do you want In Each stack?")
Shift = InputBox("What shift Do you want To Next stack?")
End Sub

'******************************************
'          Subroutine CloseImages               
'******************************************
Sub CloseImages()
Set Apps = CreateObject("MaxIm.Application")	 	
Set AllDocs = Apps.Documents
For j = 0 To AllDocs.Count-1
			If Not Img(j).Close Then
   			Wscript.Echo j, "Failed to close"
 		End If
Set Img(j) = Nothing    
Next
End Sub

'***********************************************
'           Subroutine Calculate              
' Calculate number of stacks (jint) and the    
' number of images In the partial stack       
'***********************************************
Sub Calculate()
	jint = (count - N) \ Shift + 1	'jint = number of whole stacks
	jmod = count Mod N		'jmod = number of images in partial stack, if any
End Sub

'********************************
'    Subroutine Stack_Save     
'********************************
Sub Stack_save()
SavePath = collArgs(0) & "\" & "stack" & StackIndex & ".fts"
Set Img(ii) = CreateObject("MaxIm.Document")
Img(ii).CombineImages 1, False, 0, False
Img(ii).SaveFile SavePath,3,False,3,False
Call ReadKeyWords()
ImageText(Indx) = "stack" & StackIndex & ".fts" &  "     " & DateTime & "     " & MidPoint
		
Indx = Indx + 1		
End Sub

'********************************
'     Subroutine OpenImage()   
'********************************
Sub OpenImage(i, ii)
Dim Img2
Set Img(ii) = CreateObject("MaxIm.Document")
'Set Img2 = CreateObject("MaxIm.Document")
Path = collArgs(0) & "\" & Images(i)
Img(ii).OpenFile (Path)
Img(ii).Calibrate
'Img2.OpenFile (Path)
'Img2.Calibrate
'Img(ii).ExtractBayerPlane 1
'Img2.ExtractBayerPlane 4
'Img(ii).Add(Img2)
'Img(ii).Bin(2)
Call ReadKeyWords()
	
ImageText(Indx) = Images(i) &  "     " & DateTime 
	
Indx = Indx + 1	
'Img2.Close
End Sub

'*********************************
'   Subroutine ReadKeyWords()   
'*********************************
Sub ReadKeyWords()
DateTime = (Img(ii).GetFITSKey("DATE-OBS"))     
MidPoint = (Img(ii).GetFITSKey("MIDPOINT"))  
End Sub

'*********************************
'   Subroutine CreateLog()       
'*********************************
Sub CreateLog()
Set cso = CreateObject("Scripting.FileSystemObject")
TxtLog = collArgs(0) & "\log.txt"
Set ts = cso.OpenTextFile(TxtLog, 2, True)
For kk = 0 To Indx
	ts.WriteLine(ImageText(kk))
			
Next		
End Sub